==> open-xchange-guard-ui_2.8.0.orig.tar.bz2: open-xchange-guard-ui-2.8.0/oxguard-ui/grunt/tasks/concat.js <==
module.exports = function (grunt) {

    grunt.config.merge({
        concat: {
            bundle: {
                options: {
                    footer: 'define("oxguard/bundle",["oxguard/register"],_.noop);'
                },
                files: [{
                    src: [
                        'apps/oxguard/oxguard_register.js',
                        'apps/oxguard/oxguard_core.js',
                        'apps/oxguard/core/og_http.js',
                        'apps/oxguard/settings/defaults.js',
                        'apps/mailvelope/main.js',
                        'apps/oxguard/mail/maillist.js',
                        'apps/oxguard/pgp/register.js',
                        'apps/oxguard/pgp/checker.js',
                        'apps/oxguard/pgp/mailReplyActions.js',
                        'apps/pgp_mail/util.js',
                        'apps/oxguard/mail/mail_metrics.js',
                        'apps/oxguard/mail/mail_extensions_compose.js',
                        'apps/oxguard/mail/register_compose.js',
                        'apps/oxguard/mail/oxguard_mail_compose_core.js',
                        'apps/oxguard/util.js',
                        'apps/pgp_mail/toggle-encryption.js',
                        'build/apps/oxguard/crypto/encr.js',
                        'build/apps/oxguard/crypto/jsencrypt.js',
                        'build/apps/oxguard/oxguard_data.js'
                    ],
                    dest: 'build/apps/oxguard/bundle.js'
                }]
            }
        }
    });
};

==> open-xchange-guard-ui_2.10.1.orig.tar.bz2: open-xchange-guard-ui-2.10.1/oxguard-ui/grunt/tasks/concat.js <==
module.exports = function (grunt) {

    grunt.config.merge({
        concat: {
            bundle: {
                options: {
                    footer: 'define("oxguard/bundle",["oxguard/register"],_.noop);'
                },
                files: [{
                    src: [
                        'apps/oxguard/oxguard_register.js',
                        'apps/oxguard/oxguard_core.js',
                        'apps/oxguard/core/og_http.js',
                        'apps/oxguard/settings/defaults.js',
                        'apps/oxguard/mail/maillist.js',
                        'apps/oxguard/pgp/register.js',
                        'apps/oxguard/mail/checker.js',
                        'apps/oxguard/mail/mailReplyActions.js',
                        'apps/oxguard/mail/oxguard_mail_password.js',
                        'apps/pgp_mail/util.js',
                        'apps/oxguard/mail/mail_metrics.js',
                        'apps/oxguard/mail/mail_extensions_compose.js',
                        'apps/oxguard/mail/register_compose.js',
                        'apps/oxguard/mail/oxguard_mail_compose_core.js',
                        'apps/oxguard/util.js',
                        'apps/pgp_mail/toggle-encryption.js',
                        'apps/oxguard/core/passwordView.js',
                        'build/apps/oxguard/crypto/encr.js',
                        'build/apps/oxguard/crypto/jsencrypt.js',
                        'build/apps/oxguard/oxguard_data.js'
                    ],
                    dest: 'build/apps/oxguard/bundle.js'
                }]
            }
        }
    });
};
